# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'gui/multibootusb.ui'
#
# Created by: PyQt5 UI code generator 5.5.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(629, 605)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setContentsMargins(5, 5, 5, 5)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.gridLayout_disk = QtWidgets.QGridLayout()
        self.gridLayout_disk.setContentsMargins(-1, 10, -1, -1)
        self.gridLayout_disk.setObjectName("gridLayout_disk")
        self.label_select_usb_disk = QtWidgets.QLabel(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_select_usb_disk.sizePolicy().hasHeightForWidth())
        self.label_select_usb_disk.setSizePolicy(sizePolicy)
        self.label_select_usb_disk.setMinimumSize(QtCore.QSize(100, 0))
        self.label_select_usb_disk.setObjectName("label_select_usb_disk")
        self.gridLayout_disk.addWidget(self.label_select_usb_disk, 0, 0, 1, 3)
        self.combo_drives = QtWidgets.QComboBox(self.centralwidget)
        self.combo_drives.setObjectName("combo_drives")
        self.gridLayout_disk.addWidget(self.combo_drives, 1, 0, 1, 3)
        self.button_detect_drives = QtWidgets.QPushButton(self.centralwidget)
        self.button_detect_drives.setObjectName("button_detect_drives")
        self.gridLayout_disk.addWidget(self.button_detect_drives, 1, 3, 1, 1)
        self.checkbox_all_drives = QtWidgets.QCheckBox(self.centralwidget)
        self.checkbox_all_drives.setObjectName("checkbox_all_drives")
        self.gridLayout_disk.addWidget(self.checkbox_all_drives, 0, 3, 1, 1)
        self.group_usb_details = QtWidgets.QGroupBox(self.centralwidget)
        self.group_usb_details.setAlignment(QtCore.Qt.AlignBottom|QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing)
        self.group_usb_details.setFlat(False)
        self.group_usb_details.setCheckable(False)
        self.group_usb_details.setObjectName("group_usb_details")
        self.formLayout = QtWidgets.QFormLayout(self.group_usb_details)
        self.formLayout.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.formLayout.setObjectName("formLayout")
        self.label_usb_dev = QtWidgets.QLabel(self.group_usb_details)
        self.label_usb_dev.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_usb_dev.setObjectName("label_usb_dev")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_usb_dev)
        self.usb_dev = QtWidgets.QLabel(self.group_usb_details)
        self.usb_dev.setText("")
        self.usb_dev.setObjectName("usb_dev")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.usb_dev)
        self.label_usb_vendor = QtWidgets.QLabel(self.group_usb_details)
        self.label_usb_vendor.setObjectName("label_usb_vendor")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_usb_vendor)
        self.usb_vendor = QtWidgets.QLabel(self.group_usb_details)
        self.usb_vendor.setText("")
        self.usb_vendor.setObjectName("usb_vendor")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.usb_vendor)
        self.label_usb_model = QtWidgets.QLabel(self.group_usb_details)
        self.label_usb_model.setObjectName("label_usb_model")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_usb_model)
        self.usb_model = QtWidgets.QLabel(self.group_usb_details)
        self.usb_model.setText("")
        self.usb_model.setObjectName("usb_model")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.usb_model)
        self.label_usb_size = QtWidgets.QLabel(self.group_usb_details)
        self.label_usb_size.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.label_usb_size.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_usb_size.setObjectName("label_usb_size")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_usb_size)
        self.usb_size = QtWidgets.QLabel(self.group_usb_details)
        self.usb_size.setText("")
        self.usb_size.setObjectName("usb_size")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.usb_size)
        self.label_usb_mount = QtWidgets.QLabel(self.group_usb_details)
        self.label_usb_mount.setObjectName("label_usb_mount")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.label_usb_mount)
        self.usb_mount = QtWidgets.QLabel(self.group_usb_details)
        self.usb_mount.setText("")
        self.usb_mount.setObjectName("usb_mount")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.usb_mount)
        self.label_usb_type = QtWidgets.QLabel(self.group_usb_details)
        self.label_usb_type.setObjectName("label_usb_type")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_usb_type)
        self.usb_type = QtWidgets.QLabel(self.group_usb_details)
        self.usb_type.setText("")
        self.usb_type.setObjectName("usb_type")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.usb_type)
        self.label_usb_fs = QtWidgets.QLabel(self.group_usb_details)
        self.label_usb_fs.setObjectName("label_usb_fs")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.label_usb_fs)
        self.usb_fs = QtWidgets.QLabel(self.group_usb_details)
        self.usb_fs.setText("")
        self.usb_fs.setObjectName("usb_fs")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.usb_fs)
        self.gridLayout_disk.addWidget(self.group_usb_details, 3, 0, 1, 4)
        self.horizontalLayout.addLayout(self.gridLayout_disk)
        self.gridLayout_image = QtWidgets.QGridLayout()
        self.gridLayout_image.setContentsMargins(10, 10, -1, -1)
        self.gridLayout_image.setObjectName("gridLayout_image")
        self.image_details_group = QtWidgets.QGroupBox(self.centralwidget)
        self.image_details_group.setObjectName("image_details_group")
        self.formLayout_2 = QtWidgets.QFormLayout(self.image_details_group)
        self.formLayout_2.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.formLayout_2.setObjectName("formLayout_2")
        self.label_image_type = QtWidgets.QLabel(self.image_details_group)
        self.label_image_type.setObjectName("label_image_type")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_image_type)
        self.label_image_type_value = QtWidgets.QLabel(self.image_details_group)
        self.label_image_type_value.setText("")
        self.label_image_type_value.setObjectName("label_image_type_value")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.label_image_type_value)
        self.label_image_size = QtWidgets.QLabel(self.image_details_group)
        self.label_image_size.setObjectName("label_image_size")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_image_size)
        self.label_image_size_value = QtWidgets.QLabel(self.image_details_group)
        self.label_image_size_value.setText("")
        self.label_image_size_value.setObjectName("label_image_size_value")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.label_image_size_value)
        self.label_image_bootable = QtWidgets.QLabel(self.image_details_group)
        self.label_image_bootable.setObjectName("label_image_bootable")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_image_bootable)
        self.label_image_bootable_value = QtWidgets.QLabel(self.image_details_group)
        self.label_image_bootable_value.setText("")
        self.label_image_bootable_value.setObjectName("label_image_bootable_value")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.label_image_bootable_value)
        self.gridLayout_image.addWidget(self.image_details_group, 2, 0, 1, 2)
        self.button_browse_image = QtWidgets.QPushButton(self.centralwidget)
        self.button_browse_image.setCheckable(False)
        self.button_browse_image.setFlat(False)
        self.button_browse_image.setObjectName("button_browse_image")
        self.gridLayout_image.addWidget(self.button_browse_image, 0, 1, 1, 1)
        self.label_select_image = QtWidgets.QLabel(self.centralwidget)
        self.label_select_image.setObjectName("label_select_image")
        self.gridLayout_image.addWidget(self.label_select_image, 0, 0, 1, 1)
        self.image_path = QtWidgets.QLineEdit(self.centralwidget)
        self.image_path.setObjectName("image_path")
        self.gridLayout_image.addWidget(self.image_path, 1, 0, 1, 2)
        self.horizontalLayout.addLayout(self.gridLayout_image)
        self.verticalLayout_5.addLayout(self.horizontalLayout)
        self.verticalLayout_7.addLayout(self.verticalLayout_5)
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setEnabled(True)
        self.tabWidget.setAutoFillBackground(False)
        self.tabWidget.setObjectName("tabWidget")
        self.tab_multibootusb = QtWidgets.QWidget()
        self.tab_multibootusb.setEnabled(True)
        self.tab_multibootusb.setObjectName("tab_multibootusb")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.tab_multibootusb)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setContentsMargins(5, 5, 5, 5)
        self.gridLayout.setObjectName("gridLayout")
        self.button_uninstall_distro = QtWidgets.QPushButton(self.tab_multibootusb)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icon_uninstall"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.button_uninstall_distro.setIcon(icon)
        self.button_uninstall_distro.setIconSize(QtCore.QSize(16, 18))
        self.button_uninstall_distro.setObjectName("button_uninstall_distro")
        self.gridLayout.addWidget(self.button_uninstall_distro, 0, 3, 1, 1)
        self.button_install_distro = QtWidgets.QPushButton(self.tab_multibootusb)
        self.button_install_distro.setMaximumSize(QtCore.QSize(16777215, 16777215))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icon_install"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.button_install_distro.setIcon(icon1)
        self.button_install_distro.setIconSize(QtCore.QSize(16, 18))
        self.button_install_distro.setObjectName("button_install_distro")
        self.gridLayout.addWidget(self.button_install_distro, 0, 2, 1, 1)
        self.slider_persistence = QtWidgets.QSlider(self.tab_multibootusb)
        self.slider_persistence.setEnabled(False)
        self.slider_persistence.setAutoFillBackground(False)
        self.slider_persistence.setOrientation(QtCore.Qt.Horizontal)
        self.slider_persistence.setTickPosition(QtWidgets.QSlider.TicksBothSides)
        self.slider_persistence.setObjectName("slider_persistence")
        self.gridLayout.addWidget(self.slider_persistence, 2, 0, 1, 2)
        self.installed_distros = QtWidgets.QListWidget(self.tab_multibootusb)
        self.installed_distros.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.installed_distros.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.installed_distros.setResizeMode(QtWidgets.QListView.Fixed)
        self.installed_distros.setObjectName("installed_distros")
        self.gridLayout.addWidget(self.installed_distros, 2, 2, 2, 2)
        self.label_persistence = QtWidgets.QLabel(self.tab_multibootusb)
        self.label_persistence.setEnabled(False)
        self.label_persistence.setMouseTracking(True)
        self.label_persistence.setStyleSheet("font-weight: 600")
        self.label_persistence.setObjectName("label_persistence")
        self.gridLayout.addWidget(self.label_persistence, 0, 0, 1, 1)
        self.label_persistence_value = QtWidgets.QLabel(self.tab_multibootusb)
        self.label_persistence_value.setEnabled(False)
        self.label_persistence_value.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_persistence_value.setObjectName("label_persistence_value")
        self.gridLayout.addWidget(self.label_persistence_value, 0, 1, 1, 1)
        self.horizontalLayout_2.addLayout(self.gridLayout)
        self.tabWidget.addTab(self.tab_multibootusb, "")
        self.tab_imager = QtWidgets.QWidget()
        self.tab_imager.setEnabled(True)
        self.tab_imager.setObjectName("tab_imager")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.tab_imager)
        self.horizontalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.gridLayout_9 = QtWidgets.QGridLayout()
        self.gridLayout_9.setContentsMargins(5, 5, 5, 5)
        self.gridLayout_9.setObjectName("gridLayout_9")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_9.addItem(spacerItem, 3, 2, 1, 1)
        self.button_write_image_to_disk = QtWidgets.QPushButton(self.tab_imager)
        self.button_write_image_to_disk.setObjectName("button_write_image_to_disk")
        self.gridLayout_9.addWidget(self.button_write_image_to_disk, 3, 1, 1, 1)
        self.widget_7 = QtWidgets.QWidget(self.tab_imager)
        self.widget_7.setObjectName("widget_7")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.widget_7)
        self.verticalLayout_6.setContentsMargins(5, 5, 5, 5)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.gridLayout_9.addWidget(self.widget_7, 3, 3, 1, 2)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_9.addItem(spacerItem1, 3, 0, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_9.addItem(spacerItem2, 4, 1, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.tab_imager)
        self.label_6.setObjectName("label_6")
        self.gridLayout_9.addWidget(self.label_6, 1, 1, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_9.addItem(spacerItem3, 0, 1, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_9.addItem(spacerItem4, 2, 1, 1, 1)
        self.horizontalLayout_7.addLayout(self.gridLayout_9)
        self.tabWidget.addTab(self.tab_imager, "")
        self.tab_syslinux = QtWidgets.QWidget()
        self.tab_syslinux.setObjectName("tab_syslinux")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.tab_syslinux)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.groupBox_2 = QtWidgets.QGroupBox(self.tab_syslinux)
        self.groupBox_2.setAutoFillBackground(False)
        self.groupBox_2.setObjectName("groupBox_2")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.groupBox_2)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.check_install_sys_only = QtWidgets.QRadioButton(self.groupBox_2)
        self.check_install_sys_only.setObjectName("check_install_sys_only")
        self.gridLayout_3.addWidget(self.check_install_sys_only, 0, 0, 1, 1)
        self.check_install_sys_all = QtWidgets.QRadioButton(self.groupBox_2)
        self.check_install_sys_all.setObjectName("check_install_sys_all")
        self.gridLayout_3.addWidget(self.check_install_sys_all, 1, 0, 1, 1)
        self.button_install_syslinux = QtWidgets.QPushButton(self.groupBox_2)
        self.button_install_syslinux.setObjectName("button_install_syslinux")
        self.gridLayout_3.addWidget(self.button_install_syslinux, 0, 2, 2, 1)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem5, 0, 1, 2, 1)
        self.horizontalLayout_4.addLayout(self.gridLayout_3)
        self.gridLayout_2.addWidget(self.groupBox_2, 0, 0, 1, 1)
        spacerItem6 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem6, 3, 0, 1, 1)
        self.groupBox_3 = QtWidgets.QGroupBox(self.tab_syslinux)
        self.groupBox_3.setObjectName("groupBox_3")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.groupBox_3)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.gridLayout_4 = QtWidgets.QGridLayout()
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.button_edit_syslinux = QtWidgets.QPushButton(self.groupBox_3)
        self.button_edit_syslinux.setObjectName("button_edit_syslinux")
        self.gridLayout_4.addWidget(self.button_edit_syslinux, 0, 2, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.groupBox_3)
        self.label_2.setObjectName("label_2")
        self.gridLayout_4.addWidget(self.label_2, 0, 0, 1, 1)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem7, 0, 1, 1, 1)
        self.horizontalLayout_5.addLayout(self.gridLayout_4)
        self.gridLayout_2.addWidget(self.groupBox_3, 2, 0, 1, 1)
        spacerItem8 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout_2.addItem(spacerItem8, 1, 0, 1, 1)
        self.horizontalLayout_3.addLayout(self.gridLayout_2)
        self.tabWidget.addTab(self.tab_syslinux, "")
        self.tab_testboot = QtWidgets.QWidget()
        self.tab_testboot.setObjectName("tab_testboot")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.tab_testboot)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.gridLayout_6 = QtWidgets.QGridLayout()
        self.gridLayout_6.setContentsMargins(-1, 10, -1, -1)
        self.gridLayout_6.setVerticalSpacing(20)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.groupBox_4 = QtWidgets.QGroupBox(self.tab_testboot)
        self.groupBox_4.setStyleSheet("")
        self.groupBox_4.setObjectName("groupBox_4")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.groupBox_4)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.gridLayout_8 = QtWidgets.QGridLayout()
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.combo_usb_boot_ram = QtWidgets.QComboBox(self.groupBox_4)
        self.combo_usb_boot_ram.setObjectName("combo_usb_boot_ram")
        self.combo_usb_boot_ram.addItem("")
        self.combo_usb_boot_ram.addItem("")
        self.combo_usb_boot_ram.addItem("")
        self.combo_usb_boot_ram.addItem("")
        self.combo_usb_boot_ram.addItem("")
        self.combo_usb_boot_ram.addItem("")
        self.gridLayout_8.addWidget(self.combo_usb_boot_ram, 0, 1, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_4)
        self.label_4.setObjectName("label_4")
        self.gridLayout_8.addWidget(self.label_4, 0, 0, 1, 1)
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_8.addItem(spacerItem9, 0, 5, 1, 1)
        self.boot_usb_qemu = QtWidgets.QPushButton(self.groupBox_4)
        self.boot_usb_qemu.setObjectName("boot_usb_qemu")
        self.gridLayout_8.addWidget(self.boot_usb_qemu, 0, 4, 1, 1)
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_8.addItem(spacerItem10, 0, 3, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBox_4)
        self.label_5.setObjectName("label_5")
        self.gridLayout_8.addWidget(self.label_5, 0, 2, 1, 1)
        self.verticalLayout_4.addLayout(self.gridLayout_8)
        self.gridLayout_6.addWidget(self.groupBox_4, 1, 0, 1, 1)
        self.groupBox_5 = QtWidgets.QGroupBox(self.tab_testboot)
        self.groupBox_5.setObjectName("groupBox_5")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupBox_5)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.gridLayout_7 = QtWidgets.QGridLayout()
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.label_3 = QtWidgets.QLabel(self.groupBox_5)
        self.label_3.setObjectName("label_3")
        self.gridLayout_7.addWidget(self.label_3, 0, 0, 1, 1)
        self.boot_iso_qemu = QtWidgets.QPushButton(self.groupBox_5)
        self.boot_iso_qemu.setObjectName("boot_iso_qemu")
        self.gridLayout_7.addWidget(self.boot_iso_qemu, 0, 4, 1, 1)
        spacerItem11 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_7.addItem(spacerItem11, 0, 3, 1, 1)
        self.combo_iso_boot_ram = QtWidgets.QComboBox(self.groupBox_5)
        self.combo_iso_boot_ram.setObjectName("combo_iso_boot_ram")
        self.combo_iso_boot_ram.addItem("")
        self.combo_iso_boot_ram.addItem("")
        self.combo_iso_boot_ram.addItem("")
        self.combo_iso_boot_ram.addItem("")
        self.combo_iso_boot_ram.addItem("")
        self.combo_iso_boot_ram.addItem("")
        self.gridLayout_7.addWidget(self.combo_iso_boot_ram, 0, 1, 1, 1)
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_7.addItem(spacerItem12, 0, 5, 1, 1)
        self.label = QtWidgets.QLabel(self.groupBox_5)
        self.label.setObjectName("label")
        self.gridLayout_7.addWidget(self.label, 0, 2, 1, 1)
        self.verticalLayout_3.addLayout(self.gridLayout_7)
        self.gridLayout_6.addWidget(self.groupBox_5, 0, 0, 1, 1)
        self.verticalLayout_2.addLayout(self.gridLayout_6)
        spacerItem13 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem13)
        self.tabWidget.addTab(self.tab_testboot, "")
        self.verticalLayout_7.addWidget(self.tabWidget)
        self.progressbar = QtWidgets.QProgressBar(self.centralwidget)
        self.progressbar.setProperty("value", 0)
        self.progressbar.setInvertedAppearance(False)
        self.progressbar.setObjectName("progressbar")
        self.verticalLayout_7.addWidget(self.progressbar)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 629, 19))
        self.menubar.setNativeMenuBar(True)
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menu_Help = QtWidgets.QMenu(self.menubar)
        self.menu_Help.setObjectName("menu_Help")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.action_Quit = QtWidgets.QAction(MainWindow)
        self.action_Quit.setObjectName("action_Quit")
        self.action_About = QtWidgets.QAction(MainWindow)
        self.action_About.setObjectName("action_About")
        self.menuFile.addAction(self.action_Quit)
        self.menu_Help.addAction(self.action_About)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menu_Help.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MultiBootUSB"))
        self.label_select_usb_disk.setText(_translate("MainWindow", "<b>Select USB disk</b>"))
        self.button_detect_drives.setText(_translate("MainWindow", "Detect Drives"))
        self.checkbox_all_drives.setText(_translate("MainWindow", "All Drives"))
        self.group_usb_details.setTitle(_translate("MainWindow", "USB Details"))
        self.label_usb_dev.setText(_translate("MainWindow", "Drive:"))
        self.label_usb_vendor.setText(_translate("MainWindow", "Vendor:"))
        self.label_usb_model.setText(_translate("MainWindow", "Model:"))
        self.label_usb_size.setText(_translate("MainWindow", "Size:"))
        self.label_usb_mount.setText(_translate("MainWindow", "Mount:"))
        self.label_usb_type.setText(_translate("MainWindow", "Type:"))
        self.label_usb_fs.setText(_translate("MainWindow", "Filesystem:"))
        self.image_details_group.setTitle(_translate("MainWindow", "Image Details"))
        self.label_image_type.setText(_translate("MainWindow", "Type:"))
        self.label_image_size.setText(_translate("MainWindow", "Size:"))
        self.label_image_bootable.setText(_translate("MainWindow", "Boot:"))
        self.button_browse_image.setText(_translate("MainWindow", "Browse"))
        self.label_select_image.setText(_translate("MainWindow", "<b>Select image</b>"))
        self.button_uninstall_distro.setText(_translate("MainWindow", "Uninstall distro"))
        self.button_install_distro.setText(_translate("MainWindow", "Install distro"))
        self.slider_persistence.setToolTip(_translate("MainWindow", "Choose Persistence size. Not all distros supports persistence..."))
        self.label_persistence.setText(_translate("MainWindow", "Persistence"))
        self.label_persistence_value.setText(_translate("MainWindow", "0 MB"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_multibootusb), _translate("MainWindow", "MultiBootUSB"))
        self.button_write_image_to_disk.setText(_translate("MainWindow", "Write image to USB"))
        self.label_6.setText(_translate("MainWindow", "<html><head/><body><p align=\"center\"><span style=\" font-size:14pt; font-weight:600; color:#ff0000;\">WARNING!</span></p><p align=\"center\"><span style=\" color:#000000;\">This operation destroys </span><span style=\" font-weight:600; color:#000000;\">ALL</span><span style=\" color:#000000;\"> data on the selected disk.</span></p><p align=\"center\"><span style=\" color:#000000;\">Please select the destination disk carefully.</span></p></body></html>"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_imager), _translate("MainWindow", "Write Image to disk"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Install Syslinux"))
        self.check_install_sys_only.setText(_translate("MainWindow", "Install only syslinu&x (existing configurations will not be altered)."))
        self.check_install_sys_all.setText(_translate("MainWindow", "Install syslinux and copy all re&quired files."))
        self.button_install_syslinux.setText(_translate("MainWindow", "Install"))
        self.groupBox_3.setTitle(_translate("MainWindow", "syslinux.cfg"))
        self.button_edit_syslinux.setText(_translate("MainWindow", "Edit"))
        self.label_2.setText(_translate("MainWindow", "<html><head/><body><p align=\"justify\">Edit syslinux.cfg file using the default editor. </p><p align=\"justify\">Be <span style=\" font-weight:600; color:#ff0000;\">CAREFUL</span> while editing syslinux.cfg!</p></body></html>"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_syslinux), _translate("MainWindow", "Install Syslinux"))
        self.groupBox_4.setTitle(_translate("MainWindow", "Boot USB :: Test bootable USB drive without reboot"))
        self.combo_usb_boot_ram.setItemText(0, _translate("MainWindow", "Default"))
        self.combo_usb_boot_ram.setItemText(1, _translate("MainWindow", "256"))
        self.combo_usb_boot_ram.setItemText(2, _translate("MainWindow", "512"))
        self.combo_usb_boot_ram.setItemText(3, _translate("MainWindow", "768"))
        self.combo_usb_boot_ram.setItemText(4, _translate("MainWindow", "1024"))
        self.combo_usb_boot_ram.setItemText(5, _translate("MainWindow", "2048"))
        self.label_4.setText(_translate("MainWindow", "Choose RAM size:"))
        self.boot_usb_qemu.setText(_translate("MainWindow", "Boot &USB"))
        self.label_5.setText(_translate("MainWindow", "MB"))
        self.groupBox_5.setTitle(_translate("MainWindow", "Boot ISO :: Test bootable ISOs without reboot"))
        self.label_3.setText(_translate("MainWindow", "Choose RAM size:"))
        self.boot_iso_qemu.setText(_translate("MainWindow", "Boot &ISO"))
        self.combo_iso_boot_ram.setItemText(0, _translate("MainWindow", "Default"))
        self.combo_iso_boot_ram.setItemText(1, _translate("MainWindow", "256"))
        self.combo_iso_boot_ram.setItemText(2, _translate("MainWindow", "512"))
        self.combo_iso_boot_ram.setItemText(3, _translate("MainWindow", "768"))
        self.combo_iso_boot_ram.setItemText(4, _translate("MainWindow", "1024"))
        self.combo_iso_boot_ram.setItemText(5, _translate("MainWindow", "2048"))
        self.label.setText(_translate("MainWindow", "MB"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_testboot), _translate("MainWindow", "Boot ISO/USB"))
        self.menuFile.setTitle(_translate("MainWindow", "&File"))
        self.menu_Help.setTitle(_translate("MainWindow", "&Help"))
        self.action_Quit.setText(_translate("MainWindow", "&Quit"))
        self.action_About.setText(_translate("MainWindow", "&About"))




#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Name:     update_cfg_file.py
# Purpose:  Module to manipulate distro specific and main config files.
# Authors:  Sundar
# Licence:  This file is a part of multibootusb package. You can redistribute it or modify
# under the terms of GNU General Public License, v.2 or above

import os
import re
import shutil
from .usb import *
from .gen import *
from .iso import *
from . import config
from . import grub
from . import menus


def update_distro_cfg_files(iso_link, usb_disk, distro, persistence=0):
    """
    Main function to modify/update distro specific strings on distro config files.
    :return:
    """
    usb_details = details(usb_disk)
    usb_mount = usb_details['mount_point']
    usb_uuid = usb_details['uuid']
    usb_label = usb_details['label']
#     iso_cfg_ext_dir = os.path.join(multibootusb_host_dir(), "iso_cfg_ext_dir")
    config.status_text = "Updating config files..."
    install_dir = os.path.join(usb_mount, "multibootusb", iso_basename(iso_link))
    log('Updating distro specific config files...')
    for dirpath, dirnames, filenames in os.walk(install_dir):
        for f in filenames:
            if f.endswith(".cfg") or f.endswith('.CFG') or f.endswith('.lst') or f.endswith('.conf'):
                cfg_file = os.path.join(dirpath, f)
                try:
                    string = open(cfg_file, errors='ignore').read()
                except IOError:
                    log("Unable to read ", cfg_file)
                else:
                    if not distro == "generic":
                        replace_text = r'\1/multibootusb/' + iso_basename(iso_link) + '/'
                        string = re.sub(r'([ \t =,])/', replace_text, string)
                        string = re.sub(r'linuxefi', 'linux', string)
                        string = re.sub(r'initrdefi', 'initrd', string)
                if distro == "ubuntu":
                    string = re.sub(r'boot=casper',
                                    'boot=casper cdrom-detect/try-usb=true floppy.allowed_drive_mask=0 ignore_uuid '
                                    'ignore_bootid root=UUID=' + usb_uuid + ' live-media-path=/multibootusb/'
                                    + iso_basename(iso_link) + '/casper', string)
                    # Point to correct .seed file
                    string = re.sub(r'/cdrom/preseed', '/preseed', string)
                    string = re.sub(r'live-media=\S*', 'live-media=/dev/disk/by-uuid/' + usb_uuid, string)
                    string = re.sub(r'ui gfxboot', '#ui gfxboot', string)
                    if persistence != 0:
                        string = re.sub(r'boot=casper', 'boot=casper persistent persistent-path=/multibootusb/' +
                                        iso_basename(iso_link) + "/", string)

                elif distro in ["debian", "debian-install"]:
                    string = re.sub(r'boot=live', 'boot=live ignore_bootid live-media-path=/multibootusb/' +
                                    iso_basename(iso_link) + '/live', string)
                    if persistence != 0:
                        string = re.sub(r'boot=live', 'boot=live persistent persistent-path=/multibootusb/' +
                                        iso_basename(iso_link) + "/", string)
                elif distro == 'grml':
                    string = re.sub(r'live-media-path=', 'ignore_bootid live-media-path=', string)
                elif distro == "ubuntu-server":
                    string = re.sub(r'file',
                                    'cdrom-detect/try-usb=true floppy.allowed_drive_mask=0 ignore_uuid ignore_bootid root=UUID=' +
                                    usb_uuid + ' file', string)
                elif distro == "fedora":
                    string = re.sub(r'root=\S*', 'root=live:UUID=' + usb_uuid, string)
                    if re.search(r'liveimg', string, re.I):
                        string = re.sub(r'liveimg', 'liveimg live_dir=/multibootusb/' +
                                        iso_basename(iso_link) + '/LiveOS', string)
                    elif re.search(r'rd.live.image', string, re.I):
                        string = re.sub(r'rd.live.image', 'rd.live.image rd.live.dir=/multibootusb/' +
                                        iso_basename(iso_link) + '/LiveOS', string)
                    elif re.search(r'Solus', string, re.I):
                        string = re.sub(r'initrd=', 'rd.live.dir=/multibootusb/' + iso_basename(iso_link) +
                                        '/LiveOS initrd=', string)

                    if persistence != 0:
                        if re.search(r'liveimg', string, re.I):
                            string = re.sub(r'liveimg', 'liveimg overlay=UUID=' + usb_uuid, string)
                        elif re.search(r'rd.live.image', string, re.I):
                            string = re.sub(r'rd.live.image', 'rd.live.image rw rd.live.overlay=UUID=' + usb_uuid, string)
                        string = re.sub(r' ro ', '', string)
                elif distro == 'kaspersky':
                    if not os.path.exists(os.path.join(usb_mount, 'multibootusb', iso_basename(iso_link), 'kaspersky.cfg')):
                        shutil.copyfile(resource_path(os.path.join('data', 'multibootusb', 'syslinux.cfg')),
                                        os.path.join(usb_mount, 'multibootusb', iso_basename(iso_link), 'kaspersky.cfg'))
                        config_string = kaspersky_config('kaspersky')
                        config_string = config_string.replace('$INSTALL_DIR', '/multibootusb/' + iso_basename(iso_link))
                        config_string = re.sub(r'root=live:UUID=', 'root=live:UUID=' + usb_uuid, config_string)
                        with open(os.path.join(usb_mount, 'multibootusb', iso_basename(iso_link), 'kaspersky.cfg'), "a") as f:
                            f.write(config_string)
                elif distro == "parted-magic":
                    if re.search(r'append', string, re.I):
                        string = re.sub(r'append', 'append directory=/multibootusb/' + iso_basename(iso_link), string,
                                        flags=re.I)
                    string = re.sub(r'initrd=', 'directory=/multibootusb/' + iso_basename(iso_link) + '/ initrd=',
                                    string)
                elif distro == "ubcd":
                    string = re.sub(r'iso_filename=\S*', 'directory=/multibootusb/' + iso_basename(iso_link),
                                    string, flags=re.I)
                elif distro == 'f4ubcd':
                    if not 'multibootusb' in string:
                        string = re.sub(r'/HBCD', '/multibootusb/' + iso_basename(iso_link) + '/HBCD', string)
                    if not 'multibootusb' in string:
                        string = re.sub(r'/F4UBCD', '/multibootusb/' + iso_basename(iso_link) + '/F4UBCD', string)
                elif distro == "ipcop":
                    string = re.sub(r'ipcopboot=cdrom\S*', 'ipcopboot=usb', string)
                elif distro == "puppy":
                    if 'pmedia=cd' in string:
                        string = re.sub(r'pmedia=cd\S*',
                                        'pmedia=usbflash psubok=TRUE psubdir=/multibootusb/' + iso_basename(iso_link) + '/',
                                        string)
                    elif 'rootfstype' in string:
                        string = re.sub(r'rootfstype',
                                        'pmedia=usbflash psubok=TRUE psubdir=/multibootusb/' + iso_basename(iso_link) + '/ rootfstype',
                                        string)
                elif distro == "slax":
                    string = re.sub(r'initrd=',
                                    r'from=/multibootusb/' + iso_basename(iso_link) + '/slax fromusb initrd=', string)
                elif distro == "finnix":
                    string = re.sub(r'initrd=',
                                    r'finnixdir=/multibootusb/' + iso_basename(iso_link) + '/finnix initrd=', string)
                elif distro == "knoppix":
                    string = re.sub(r'initrd=', 'knoppix_dir=/multibootusb/' + iso_basename(iso_link) + '/KNOPPIX initrd=', string)
                elif distro == "gentoo":
                    string = re.sub(r'append ',
                                    'append real_root=' + usb_disk + ' slowusb subdir=/multibootusb/' +
                                    iso_basename(iso_link) + '/ ', string, flags=re.I)
                    string = re.sub(r'slowusb', 'slowusb loop=/multibootusb/' +
                                    iso_basename(iso_link) + '/liberte/boot/root-x86.sfs', string, flags=re.I)
                    string = re.sub(r'cdroot_hash=\S*', '', string, flags=re.I)

                elif distro == "systemrescuecd":
                    rows = []
                    subdir = '/multibootusb/' + iso_basename(iso_link)
                    for line in string.splitlines(True):
                        addline = True
                        if re.match(r'append.*--.*', line, flags=re.I):
                            line = re.sub(r'(append)(.*)--(.*)', r'\1\2subdir=' + subdir + r' --\3 subdir=' + subdir,
                                          line, flags=re.I)
                        elif re.match(r'append', line, flags=re.I):
                            line = re.sub(r'(append)', r'\1 subdir=' + subdir, line, flags=re.I)
                        elif re.match(r'label rescue(32|64)_1', line, flags=re.I):
                            rows.append(line)
                            rows.append('append subdir=%s\n' % (subdir,))
                            addline = False

                        if addline:
                            rows.append(line)

                    string = ''.join(rows)
                elif distro in ["arch", "chakra"]:
                    string = re.sub(r'isolabel=\S*',
                                    'isodevice=/dev/disk/by-uuid/' + usb_uuid, string, flags=re.I)
                    string = re.sub(r'isobasedir=',
                                    'isobasedir=/multibootusb/' + iso_basename(iso_link) + '/', string, flags=re.I)
                    string = re.sub(r'ui gfxboot', '# ui gfxboot', string)  # Bug in the isolinux package
                    if 'manjaro' in string:
                        if not os.path.exists(os.path.join(usb_mount, '.miso')):
                            with open(os.path.join(usb_mount, '.miso'), "w") as f:
                                f.write('')
                elif distro == "kaos":
                    string = re.sub(r'kdeosisolabel=\S*',
                                    'kdeosisodevice=/dev/disk/by-uuid/' + usb_uuid, string, flags=re.I)
                    string = re.sub(r'append',
                                    'append kdeosisobasedir=/multibootusb/' + iso_basename(iso_link) + '/kdeos/', string, flags=re.I)
                    string = re.sub(r'ui gfxboot', '# ui gfxboot', string)  # Bug in the isolinux package
                elif distro in ["suse", "opensuse"]:
                    if re.search(r'opensuse_12', string, re.I):
                        string = re.sub(r'append',
                                        'append loader=syslinux isofrom_system=/dev/disk/by-uuid/' + usb_uuid + ":/" +
                                        iso_name(iso_link), string, flags=re.I)
                    else:
                        string = re.sub(r'append',
                                        'append loader=syslinux isofrom_device=/dev/disk/by-uuid/' + usb_uuid +
                                        ' isofrom_system=/multibootusb/' + iso_basename(iso_link) + '/' + iso_name(iso_link),
                                        string, flags=re.I)
                elif distro == 'opensuse-install':
                    string = re.sub(r'splash=silent', 'splash=silent install=hd:/dev/disk/by-uuid/'
                                    + config.usb_uuid + '/multibootusb/' + iso_basename(iso_link), string)
                elif distro == "pclinuxos":
                    string = re.sub(r'livecd=',
                                    'fromusb livecd=' + '/multibootusb/' + iso_basename(iso_link) + '/',
                                    string)
                    string = re.sub(r'prompt', '#prompt', string)
                    string = re.sub(r'ui gfxboot.com', '#ui gfxboot.com', string)
                    string = re.sub(r'timeout', '#timeout', string)
                elif distro == "wifislax":
                    string = re.sub(r'vmlinuz',
                                    'vmlinuz from=multibootusb/' + iso_basename(iso_link) + ' noauto', string)
                    string = re.sub(r'vmlinuz2',
                                    'vmlinuz2 from=multibootusb/' + iso_basename(iso_link) + ' noauto', string)
                elif distro == "porteus":
                    string = re.sub(r'APPEND',
                                    'APPEND from=/multibootusb/' + iso_basename(iso_link) + ' noauto', string)
                    string = re.sub(r'vmlinuz2',
                                    'vmlinuz2 from=multibootusb/' + iso_basename(iso_link) + ' noauto', string)
                elif distro == "hbcd":
                    if not 'multibootusb' in string:
                        string = re.sub(r'/HBCD', '/multibootusb/' + iso_basename(iso_link) + '/HBCD', string)
                elif distro == "zenwalk":
                    string = re.sub(r'initrd=',
                                    'from=/multibootusb/' + iso_basename(iso_link) + '/' + iso_name(iso_link) + ' initrd=',
                                    string)
                elif distro == "mageialive":
                    string = re.sub(r'LABEL=\S*', 'LABEL=' + usb_label, string)
                elif distro == "antix":
                    string = re.sub(r'APPEND', 'image_dir=/multibootusb/' + iso_basename(iso_link), string)
                elif distro == "solydx":
                    string = re.sub(r'live-media-path=', 'live-media-path=/multibootusb/' + iso_basename(iso_link),
                                    string)
                elif distro == "salix-live":
                    string = re.sub(r'iso_path', '/multibootusb/' + iso_basename(iso_link) + '/' + iso_name(iso_link),
                                    string)
                    string = re.sub(r'initrd', 'fromiso=/multibootusb/' + iso_basename(iso_link) + '/' +
                                    iso_name(iso_link) + ' initrd', string)
                elif distro == 'alt-linux':
                    string = re.sub(r':cdrom', ':disk', string)
                elif distro == 'fsecure':
                    string = re.sub(r'APPEND ramdisk_size', 'APPEND noprompt ' + 'knoppix_dir=/multibootusb/' + iso_basename(iso_link)
                                    + '/KNOPPIX ramdisk_size', string)
                elif distro == 'alpine':
                    string = re.sub(r'modules', 'alpine_dev=usbdisk:vfat modules', string)
                elif config.distro == 'trinity-rescue':
                    # USB disk must have volume label to work properly
                    string = re.sub(r'initrd=', 'vollabel=' + config.usb_label + ' initrd=', string)
                    string = re.sub(r'root=\S*', 'root=/dev/ram0', string, flags=re.I)

                config_file = open(cfg_file, "w")
                config_file.write(string)
                config_file.close()

    update_mbusb_cfg_file(iso_link, usb_uuid, usb_mount, distro)
    grub.mbusb_update_grub_cfg()

    # Ensure that isolinux.cfg file is copied as syslinux.cfg to boot correctly.
    for dirpath, dirnames, filenames in os.walk(install_dir):
        for f in filenames:
            if f.lower().endswith("isolinux.cfg"):
                if not os.path.exists(os.path.join(dirpath, "syslinux.cfg")):
                    try:
                        shutil.copyfile(os.path.join(dirpath, f), os.path.join(dirpath, "syslinux.cfg"))
                    except Exception as e:
                        log('Copying isolinux to syslinux failed...')
                        log(e)
                else:
                    continue

    # Assertain if the entry is made..
    sys_cfg_file = os.path.join(config.usb_mount, "multibootusb", "syslinux.cfg")
    if gen.check_text_in_file(sys_cfg_file, iso_basename(config.image_path)):
        log('Updated entry in syslinux.cfg...')
    else:
        log('Unable to update entry in syslinux.cfg...')

    # Check if bootx64.efi is replaced by distro
    efi_grub_img = os.path.join(config.usb_mount, 'EFI', 'BOOT', 'bootx64.efi')
    if not os.path.exists(efi_grub_img):
        gen.log('EFI image does not exist. Copying now...')
        shutil.copy2(resource_path(os.path.join("data", "EFI", "BOOT", "bootx64.efi")),
                                   os.path.join(config.usb_mount, 'EFI', 'BOOT'))
    elif gen.grub_efi_exist(efi_grub_img) is False:
        gen.log('EFI image overwritten by distro install. Replacing it now...')
        shutil.copy2(resource_path(os.path.join("data", "EFI", "BOOT", "bootx64.efi")),
                     os.path.join(config.usb_mount, 'EFI', 'BOOT'))
    else:
        gen.log('multibootusb EFI image already exist. Not copying...')


def update_mbusb_cfg_file(iso_link, usb_uuid, usb_mount, distro):
    """
    Update main multibootusb suslinux.cfg file after distro is installed.
    :return:
    """
    if platform.system() == 'Linux':
        os.sync()
    log('Updating multibootusb config file...')
    sys_cfg_file = os.path.join(usb_mount, "multibootusb", "syslinux.cfg")
    install_dir = os.path.join(usb_mount, "multibootusb", iso_basename(iso_link))
    if os.path.exists(sys_cfg_file):

        if distro == "hbcd":
            if os.path.exists(os.path.join(usb_mount, "multibootusb", "menu.lst")):
                _config_file = os.path.join(usb_mount, "multibootusb", "menu.lst")
                config_file = open(_config_file, "w")
                string = re.sub(r'/HBCD', '/multibootusb/' + iso_basename(iso_link) + '/HBCD', _config_file)
                config_file.write(string)
                config_file.close()
            with open(sys_cfg_file, "a") as f:
                f.write("#start " + iso_basename(config.image_path) + "\n")
                f.write("LABEL " + iso_basename(config.image_path) + "\n")
                f.write("MENU LABEL " + iso_basename(config.image_path) + "\n")
                f.write("BOOT " + '/multibootusb/' + iso_basename(iso_link) + '/' + isolinux_bin_dir(iso_link).replace("\\", "/") + '/' + distro + '.bs' + "\n")
                f.write("#end " + iso_basename(config.image_path) + "\n")
        elif distro == "Windows":
            if os.path.exists(sys_cfg_file):
                config_file = open(sys_cfg_file, "a")
                config_file.write("#start " + iso_basename(iso_link) + "\n")
                config_file.write("LABEL " + iso_basename(iso_link) + "\n")
                config_file.write("MENU LABEL " + iso_basename(iso_link) + "\n")
                config_file.write("KERNEL chain.c32 hd0 1 ntldr=/bootmgr" + "\n")
                config_file.write("#end " + iso_basename(iso_link) + "\n")
                config_file.close()
        elif distro == 'f4ubcd':
            if os.path.exists(sys_cfg_file):
                config_file = open(sys_cfg_file, "a")
                config_file.write("#start " + iso_basename(iso_link) + "\n")
                config_file.write("LABEL " + iso_basename(iso_link) + "\n")
                config_file.write("MENU LABEL " + iso_basename(iso_link) + "\n")
                config_file.write("KERNEL grub.exe" + "\n")
                config_file.write('APPEND --config-file=/multibootusb/' + iso_basename(config.image_path) + '/menu.lst' + "\n")
                config_file.write("#end " + iso_basename(iso_link) + "\n")
                config_file.close()
        elif distro == 'kaspersky':
            if os.path.exists(sys_cfg_file):
                config_file = open(sys_cfg_file, "a")
                config_file.write("#start " + iso_basename(iso_link) + "\n")
                config_file.write("LABEL " + iso_basename(iso_link) + "\n")
                config_file.write("MENU LABEL " + iso_basename(iso_link) + "\n")
                config_file.write("CONFIG " + '/multibootusb/' + iso_basename(config.image_path) + '/kaspersky.cfg' + "\n")
                config_file.write("#end " + iso_basename(iso_link) + "\n")
                config_file.close()
        elif distro == 'grub4dos':
            update_menu_lst()
        elif distro == 'grub4dos_iso':
            update_grub4dos_iso_menu()
        else:
            config_file = open(sys_cfg_file, "a")
            config_file.write("#start " + iso_basename(iso_link) + "\n")
            config_file.write("LABEL " + iso_basename(iso_link) + "\n")
            config_file.write("MENU LABEL " + iso_basename(iso_link) + "\n")
            if distro == "salix-live":
                if os.path.exists(os.path.join(config.usb_mount, 'multibootusb', iso_basename(iso_link), 'boot', 'grub2-linux.img')):
                    config_file.write(
                        "LINUX " + '/multibootusb/' + iso_basename(iso_link) + '/boot/grub2-linux.img' + "\n")
                else:
                    config_file.write("BOOT " + '/multibootusb/' + iso_basename(iso_link) + '/' + isolinux_bin_dir(iso_link).replace("\\", "/") + '/' + distro + '.bs' + "\n")
            elif distro == "pclinuxos":
                config_file.write("kernel " + '/multibootusb/' + iso_basename(iso_link) + '/isolinux/vmlinuz' + "\n")
                config_file.write("append livecd=livecd root=/dev/rd/3 acpi=on vga=788 keyb=us vmalloc=256M nokmsboot "
                                  "fromusb root=UUID=" + usb_uuid + " bootfromiso=/multibootusb/" +
                                  iso_basename(iso_link) + "/" + iso_name(iso_link) + " initrd=/multibootusb/"
                                  + iso_basename(iso_link) + '/isolinux/initrd.gz' + "\n")
            elif distro == "memtest":
                config_file.write("kernel " + '/multibootusb/' + iso_basename(iso_link) + '/BOOT/MEMTEST.IMG\n')

            elif distro == "sgrubd2" or config.distro == 'raw_iso':
                config_file.write("LINUX memdisk\n")
                config_file.write("INITRD " + "/multibootusb/" + iso_basename(iso_link) + '/' + iso_name(iso_link) + '\n')
                config_file.write("APPEND iso\n")

            elif distro == 'ReactOS':
                config_file.write("COM32 mboot.c32" + '\n')
                config_file.write("APPEND /loader/setupldr.sys" + '\n')
            elif distro == 'pc-unlocker':
                config_file.write("kernel ../ldntldr" + '\n')
                config_file.write("append initrd=../ntldr" + '\n')
            elif distro == 'pc-tool':
                config_file.write(menus.pc_tool_config(syslinux=True, grub=False))
            elif distro == 'grub2only':
                config_file.write(menus.grub2only())
            elif distro == 'memdisk_iso':
                print(menus.memdisk_iso_cfg(syslinux=True, grub=False))
                config_file.write(menus.memdisk_iso_cfg(syslinux=True, grub=False))
            elif distro == 'memdisk_img':
                config_file.write(menus.memdisk_img_cfg(syslinux=True, grub=False))
            else:
                if isolinux_bin_exist(config.image_path) is True:
                    if distro == "generic":
                        distro_syslinux_install_dir = isolinux_bin_dir(iso_link)
                        if isolinux_bin_dir(iso_link) != "/":
                            distro_sys_install_bs = os.path.join(usb_mount, isolinux_bin_dir(iso_link)) + '/' + distro + '.bs'
                        else:
                            distro_sys_install_bs = '/' + distro + '.bs'
                    else:
                        distro_syslinux_install_dir = install_dir
                        distro_syslinux_install_dir = distro_syslinux_install_dir.replace(usb_mount, '')
                        distro_sys_install_bs = distro_syslinux_install_dir + '/' + isolinux_bin_dir(iso_link) + '/' + distro + '.bs'

                    distro_sys_install_bs = "/" + distro_sys_install_bs.replace("\\", "/")  # Windows path issue.

                    if config.syslinux_version == '3':
                        config_file.write("CONFIG /multibootusb/" + iso_basename(iso_link) + '/' + isolinux_bin_dir(iso_link).replace("\\", "/") + '/isolinux.cfg\n')
                        config_file.write("APPEND /multibootusb/" + iso_basename(iso_link) + '/' + isolinux_bin_dir(iso_link).replace("\\", "/") + '\n')
                        config_file.write("# Delete or comment above two lines using # and remove # from below line if "
                                          "you get not a COM module error.\n")
                        config_file.write("#BOOT " + distro_sys_install_bs.replace("//", "/") + "\n")
                    else:
                        config_file.write("BOOT " + distro_sys_install_bs.replace("//", "/") + "\n")

            config_file.write("#end " + iso_basename(iso_link) + "\n")
            config_file.close()


def kaspersky_config(distro):
    if distro == 'kaspersky':
        return """
menu label Kaspersky Rescue Disk
  kernel $INSTALL_DIR/boot/rescue
  append root=live:UUID= live_dir=$INSTALL_DIR/rescue/LiveOS/ subdir=$INSTALL_DIR/rescue/LiveOS/ looptype=squashfs rootfstype=auto vga=791 init=/linuxrc loop=$INSTALL_DIR/rescue/LiveOS/squashfs.img initrd=$INSTALL_DIR/boot/rescue.igz lang=en udev liveimg splash quiet doscsi nomodeset
label text
  menu label Kaspersky Rescue Disk - Text Mode
  kernel $INSTALL_DIR/boot/rescue
  append root=live:UUID= live_dir=$INSTALL_DIR/rescue/LiveOS/ subdir=$INSTALL_DIR/rescue/LiveOS/ rootfstype=auto vga=791 init=/linuxrc loop=/multiboot/rescue/LiveOS/squashfs.img initrd=$INSTALL_DIR/boot/rescue.igz SLUG_lang=en udev liveimg quiet nox shell noresume doscsi nomodeset
label hwinfo
  menu label Kaspersky Hardware Info
  kernel $INSTALL_DIR/boot/rescue
  append root=live:UUID= live_dir=$INSTALL_DIR/rescue/LiveOS/ subdir=$INSTALL_DIR/rescue/LiveOS/ rootfstype=auto vga=791 init=/linuxrc loop=$INSTALL_DIR/rescue/LiveOS/squashfs.img initrd=$INSTALL_DIR/boot/rescue.igz SLUG_lang=en udev liveimg quiet softlevel=boot nox hwinfo noresume doscsi nomodeset """


def update_menu_lst():
    sys_cfg_file = os.path.join(config.usb_mount, "multibootusb", "syslinux.cfg")
#     install_dir = os.path.join(config.usb_mount, "multibootusb", iso_basename(config.image_path))
    menu_lst = iso_menu_lst_path(config.image_path).replace("\\", "/")
    with open(sys_cfg_file, "a") as f:
        f.write("#start " + iso_basename(config.image_path) + "\n")
        f.write("LABEL " + iso_basename(config.image_path) + "\n")
        f.write("MENU LABEL " + iso_basename(config.image_path) + "\n")
        f.write("KERNEL grub.exe" + "\n")
        f.write('APPEND --config-file=/' + menu_lst + "\n")
        f.write("#end " + iso_basename(config.image_path) + "\n")


def update_grub4dos_iso_menu():
        sys_cfg_file = os.path.join(config.usb_mount, "multibootusb", "syslinux.cfg")
        install_dir = os.path.join(config.usb_mount, "multibootusb", iso_basename(config.image_path))
        menu_lst_file = os.path.join(install_dir, 'menu.lst')
        with open(menu_lst_file, "w") as f:
            f.write("title Boot " + iso_name(config.image_path) + "\n")
            f.write("find --set-root --ignore-floppies --ignore-cd /multibootusb/" + iso_basename(config.image_path) + '/'
                    + iso_name(config.image_path) + "\n")
            f.write("map --heads=0 --sectors-per-track=0 /multibootusb/" + iso_basename(config.image_path)
                    + '/' + iso_name(config.image_path) + ' (hd32)' + "\n")
            f.write("map --hook" + "\n")
            f.write("chainloader (hd32)")

        with open(sys_cfg_file, "a") as f:
            f.write("#start " + iso_basename(config.image_path) + "\n")
            f.write("LABEL " + iso_basename(config.image_path) + "\n")
            f.write("MENU LABEL " + iso_basename(config.image_path) + "\n")
            f.write("KERNEL grub.exe" + "\n")
            f.write('APPEND --config-file=/multibootusb/' + iso_basename(config.image_path) + '/menu.lst'  + "\n")
            f.write("#end " + iso_basename(config.image_path) + "\n")



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# Name:     setup.py
# Purpose:  Module to create packages or install multibootusb package from source
# Authors:  Sundar
# Licence:  This file is a part of multibootusb package. You can redistribute it or modify
# under the terms of GNU General Public License, v.2 or above

from distutils.core import setup
#from setuptools import setup, find_packages
import os
from scripts.gen import mbusb_version


Version = mbusb_version()


def get_data(_dir):
    """
    Get path to all files, including sub directories
    :param _dir: Path to top level directory
    :return: Path to files as list
    """
    data = []
    for dirpath, dirnames, filenames in os.walk(_dir):
        for f in filenames:
            cfg_file = os.path.join(dirpath, f)
            data.append(cfg_file)
    return data


def root_files(_dir):
    """
    Get path to all files of root directories
    :param _dir: Path to a directory
    :return: Path to files as list
    """
    data = []
    for _file in os.listdir(_dir):
        path = os.path.join(_dir, _file)
        if not os.path.isdir(path):
            data.append(path)
    return data


setup(
    name='multibootusb',
    version=Version,
    packages=['scripts', 'scripts.pyudev', 'scripts.pyudev.device', 'scripts.pyudev._ctypeslib', 'scripts.pyudev._os',
              'scripts.gui', 'scripts.progressbar'],
    #packages=find_packages(),
    scripts=['multibootusb', 'multibootusb-pkexec'],
    platforms=['Linux'],
    url='http://multibootusb.org/',
    license='General Public License (GPL)',
    author='Sundar',
    author_email='feedback.multibootusb@gmail.com',
    description='Create multi boot live Linux on a USB disk...',
    long_description='multibootusb is an advanced cross-platform application for installing/uninstalling Linux operating systems on to a single USB flash drives.',
    data_files=[("/usr/share/applications", ["data/multibootusb.desktop"]),
                ('/usr/share/pixmaps', ["data/tools/multibootusb.png"]),
                ('/usr/share/polkit-1/actions/', ['org.debian.pkexec.run-multibootusb.policy']),
                ('/usr/share/multibootusb/data/tools', ["data/tools/mbr.bin"]),
                ('/usr/share/multibootusb/data', ["data/version.txt"]),
                ('/usr/share/multibootusb/data/tools', ["data/tools/multibootusb.png"]),
                ('/usr/share/multibootusb/data/tools/dd', ["data/tools/dd/dd.exe"]),
                ('/usr/share/multibootusb/data/tools/dd', ["data/tools/dd/diskio.dll"]),
                ('/usr/share/multibootusb/data/tools/mkfs', ["data/tools/mkfs/mke2fs.exe"]),
                ('/usr/share/multibootusb/data/EFI/BOOT', get_data('data/EFI')),
                ('/usr/share/multibootusb/data/multibootusb', ["data/multibootusb/chain.c32"]),
                ('/usr/share/multibootusb/data/multibootusb', ["data/multibootusb/bg.png"]),
                ('/usr/share/multibootusb/data/multibootusb', ["data/multibootusb/extlinux.cfg"]),
                ('/usr/share/multibootusb/data/multibootusb', ["data/multibootusb/grub.exe"]),
                ('/usr/share/multibootusb/data/multibootusb', ["data/multibootusb/memdisk"]),
                ('/usr/share/multibootusb/data/multibootusb', ["data/multibootusb/menu.c32"]),
                ('/usr/share/multibootusb/data/multibootusb', ["data/multibootusb/menu.lst"]),
                ('/usr/share/multibootusb/data/multibootusb', ["data/multibootusb/syslinux.cfg"]),
                ('/usr/share/multibootusb/data/multibootusb', ["data/multibootusb/vesamenu.c32"]),
                ('/usr/share/multibootusb/data/multibootusb/grub', root_files('data/multibootusb/grub')),
                ('/usr/share/multibootusb/data/multibootusb/grub/i386-pc', get_data('data/multibootusb/grub')),
                ('/usr/share/multibootusb/data/tools/syslinux', get_data('data/tools/syslinux'))]
)



# -*- coding: utf-8 -*-
# Copyright (C) 2010, 2011, 2012, 2013 Sebastian Wiesner <lunaryorn@gmail.com>

# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by the
# Free Software Foundation; either version 2.1 of the License, or (at your
# option) any later version.

# This library is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
# for more details.

# You should have received a copy of the GNU Lesser General Public License
# along with this library; if not, write to the Free Software Foundation,
# Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA


"""
    pyudev._ctypeslib.libudev
    =========================

    Wrapper types for libudev.  Use ``libudev`` attribute to access libudev
    functions.

    .. moduleauthor::  Sebastian Wiesner  <lunaryorn@gmail.com>
"""

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals

from ctypes import c_char
from ctypes import c_char_p
from ctypes import c_int
from ctypes import c_uint
from ctypes import c_ulonglong
from ctypes import CDLL
from ctypes import Structure
from ctypes import POINTER

from ctypes.util import find_library

from ._errorcheckers import check_errno_on_nonzero_return
from ._errorcheckers import check_errno_on_null_pointer_return
from ._errorcheckers import check_negative_errorcode


class udev(Structure): # pylint: disable=invalid-name
    """
    Dummy for ``udev`` structure.
    """
    # pylint: disable=too-few-public-methods
    pass

udev_p = POINTER(udev) # pylint: disable=invalid-name


class udev_enumerate(Structure): # pylint: disable=invalid-name
    """
    Dummy for ``udev_enumerate`` structure.
    """
    # pylint: disable=too-few-public-methods
    pass

udev_enumerate_p = POINTER(udev_enumerate) # pylint: disable=invalid-name


class udev_list_entry(Structure): # pylint: disable=invalid-name
    """
    Dummy for ``udev_list_entry`` structure.
    """
    # pylint: disable=too-few-public-methods
    pass

udev_list_entry_p = POINTER(udev_list_entry) # pylint: disable=invalid-name


class udev_device(Structure): # pylint: disable=invalid-name
    """
    Dummy for ``udev_device`` structure.
    """
    # pylint: disable=too-few-public-methods
    pass

udev_device_p = POINTER(udev_device) # pylint: disable=invalid-name


class udev_monitor(Structure): # pylint: disable=invalid-name
    """
    Dummy for ``udev_device`` structure.
    """
    # pylint: disable=too-few-public-methods
    pass

udev_monitor_p = POINTER(udev_monitor) # pylint: disable=invalid-name

class udev_hwdb(Structure): # pylint: disable=invalid-name
    """
    Dummy for ``udev_hwdb`` structure.
    """
    # pylint: disable=too-few-public-methods
    pass

udev_hwdb_p = POINTER(udev_hwdb) # pylint: disable=invalid-name


dev_t = c_ulonglong # pylint: disable=invalid-name


SIGNATURES = dict(
   # context
   udev_new=([], udev_p),
   udev_unref=([udev_p], None),
   udev_ref=([udev_p], udev_p),
   udev_get_sys_path=([udev_p], c_char_p),
   udev_get_dev_path=([udev_p], c_char_p),
   udev_get_run_path=([udev_p], c_char_p),
   udev_get_log_priority=([udev_p], c_int),
   udev_set_log_priority=([udev_p, c_int], None),
   udev_enumerate_new=([udev_p], udev_enumerate_p),
   udev_enumerate_ref=([udev_enumerate_p], udev_enumerate_p),
   udev_enumerate_unref=([udev_enumerate_p], None),
   udev_enumerate_add_match_subsystem=([udev_enumerate_p, c_char_p], c_int),
   udev_enumerate_add_nomatch_subsystem=([udev_enumerate_p, c_char_p], c_int),
   udev_enumerate_add_match_property=(
      [udev_enumerate_p, c_char_p, c_char_p],
      c_int
   ),
   udev_enumerate_add_match_sysattr=(
      [udev_enumerate_p, c_char_p, c_char_p],
      c_int
   ),
   udev_enumerate_add_nomatch_sysattr=(
      [udev_enumerate_p, c_char_p, c_char_p],
      c_int
   ),
   udev_enumerate_add_match_tag=([udev_enumerate_p, c_char_p], c_int),
   udev_enumerate_add_match_sysname=([udev_enumerate_p, c_char_p], c_int),
   udev_enumerate_add_match_parent=([udev_enumerate_p, udev_device_p], c_int),
   udev_enumerate_add_match_is_initialized=([udev_enumerate_p], c_int),
   udev_enumerate_scan_devices=([udev_enumerate_p], c_int),
   udev_enumerate_get_list_entry=([udev_enumerate_p], udev_list_entry_p),
   # list entries
   udev_list_entry_get_next=([udev_list_entry_p], udev_list_entry_p),
   udev_list_entry_get_name=([udev_list_entry_p], c_char_p),
   udev_list_entry_get_value=([udev_list_entry_p], c_char_p),
   # devices
   udev_device_ref=([udev_device_p], udev_device_p),
   udev_device_unref=([udev_device_p], None),
   udev_device_new_from_syspath=([udev_p, c_char_p], udev_device_p),
   udev_device_new_from_subsystem_sysname=(
      [udev_p, c_char_p, c_char_p],
      udev_device_p
   ),
   udev_device_new_from_devnum=([udev_p, c_char, dev_t], udev_device_p),
   udev_device_new_from_device_id=([udev_p, c_char_p], udev_device_p),
   udev_device_new_from_environment=([udev_p], udev_device_p),
   udev_device_get_parent=([udev_device_p], udev_device_p),
   udev_device_get_parent_with_subsystem_devtype=(
      [udev_device_p, c_char_p, c_char_p],
      udev_device_p
   ),
   udev_device_get_devpath=([udev_device_p], c_char_p),
   udev_device_get_subsystem=([udev_device_p], c_char_p),
   udev_device_get_syspath=([udev_device_p], c_char_p),
   udev_device_get_sysnum=([udev_device_p], c_char_p),
   udev_device_get_sysname=([udev_device_p], c_char_p),
   udev_device_get_driver=([udev_device_p], c_char_p),
   udev_device_get_devtype=([udev_device_p], c_char_p),
   udev_device_get_devnode=([udev_device_p], c_char_p),
   udev_device_get_property_value=([udev_device_p, c_char_p], c_char_p),
   udev_device_get_sysattr_value=([udev_device_p, c_char_p], c_char_p),
   udev_device_get_devnum=([udev_device_p], dev_t),
   udev_device_get_action=([udev_device_p], c_char_p),
   udev_device_get_seqnum=([udev_device_p], c_ulonglong),
   udev_device_get_is_initialized=([udev_device_p], c_int),
   udev_device_get_usec_since_initialized=([udev_device_p], c_ulonglong),
   udev_device_get_devlinks_list_entry=([udev_device_p], udev_list_entry_p),
   udev_device_get_tags_list_entry=([udev_device_p], udev_list_entry_p),
   udev_device_get_properties_list_entry=([udev_device_p], udev_list_entry_p),
   udev_device_get_sysattr_list_entry=([udev_device_p], udev_list_entry_p),
   udev_device_set_sysattr_value=([udev_device_p, c_char_p, c_char_p], c_int),
   udev_device_has_tag=([udev_device_p, c_char_p], c_int),
   # monitoring
   udev_monitor_ref=([udev_monitor_p], udev_monitor_p),
   udev_monitor_unref=([udev_monitor_p], None),
   udev_monitor_new_from_netlink=([udev_p, c_char_p], udev_monitor_p),
   udev_monitor_enable_receiving=([udev_monitor_p], c_int),
   udev_monitor_set_receive_buffer_size=([udev_monitor_p, c_int], c_int),
   udev_monitor_get_fd=([udev_monitor_p], c_int),
   udev_monitor_receive_device=([udev_monitor_p], udev_device_p),
   udev_monitor_filter_add_match_subsystem_devtype=(
           [udev_monitor_p, c_char_p, c_char_p], c_int),
   udev_monitor_filter_add_match_tag=([udev_monitor_p, c_char_p], c_int),
   udev_monitor_filter_update=([udev_monitor_p], c_int),
   udev_monitor_filter_remove=([udev_monitor_p], c_int),
   # hwdb
   udev_hwdb_ref=([udev_hwdb_p], udev_hwdb_p),
   udev_hwdb_unref=([udev_hwdb_p], None),
   udev_hwdb_new=([udev_p], udev_hwdb_p),
   udev_hwdb_get_properties_list_entry=(
      [udev_hwdb_p, c_char_p, c_uint],
      udev_list_entry_p
   )
)


ERROR_CHECKERS = dict(
   udev_device_get_action=None,
   udev_device_get_devlinks_list_entry=None,
   udev_device_get_devnode=None,
   udev_device_get_devnum=None,
   udev_device_get_devpath=None,
   udev_device_get_devtype=None,
   udev_device_get_driver=None,
   udev_device_get_is_initialized=None,
   udev_device_get_parent=None,
   udev_device_get_parent_with_subsystem_devtype=None,
   udev_device_get_properties_list_entry=None,
   udev_device_get_property_value=None,
   udev_device_get_seqnum=None,
   udev_device_get_subsystem=None,
   udev_device_get_sysattr_list_entry=None,
   udev_device_get_sysattr_value=None,
   udev_device_get_sysname=None,
   udev_device_get_sysnum=None,
   udev_device_get_syspath=None,
   udev_device_get_tags_list_entry=None,
   udev_device_get_usec_since_initialized=None,
   udev_device_has_tag=None,
   udev_device_new_from_device_id=None,
   udev_device_new_from_devnum=None,
   udev_device_new_from_environment=None,
   udev_device_new_from_subsystem_sysname=None,
   udev_device_new_from_syspath=None,
   udev_device_ref=None,
   udev_device_unref=None,
   udev_device_set_sysattr_value=check_negative_errorcode,
   udev_enumerate_add_match_parent=check_negative_errorcode,
   udev_enumerate_add_match_subsystem=check_negative_errorcode,
   udev_enumerate_add_nomatch_subsystem=check_negative_errorcode,
   udev_enumerate_add_match_property=check_negative_errorcode,
   udev_enumerate_add_match_sysattr=check_negative_errorcode,
   udev_enumerate_add_nomatch_sysattr=check_negative_errorcode,
   udev_enumerate_add_match_tag=check_negative_errorcode,
   udev_enumerate_add_match_sysname=check_negative_errorcode,
   udev_enumerate_add_match_is_initialized=check_negative_errorcode,
   udev_enumerate_get_list_entry=None,
   udev_enumerate_new=None,
   udev_enumerate_ref=None,
   udev_enumerate_scan_devices=None,
   udev_enumerate_unref=None,
   udev_get_dev_path=None,
   udev_get_log_priority=None,
   udev_get_run_path=None,
   udev_get_sys_path=None,
   udev_hwdb_get_properties_list_entry=None,
   udev_hwdb_new=None,
   udev_hwdb_ref=None,
   udev_hwdb_unref=None,
   udev_list_entry_get_name=None,
   udev_list_entry_get_next=None,
   udev_list_entry_get_value=None,
   udev_monitor_set_receive_buffer_size=check_errno_on_nonzero_return,
   # libudev doc says, enable_receiving returns a negative errno, but tests
   # show that this is not reliable, so query the real error code
   udev_monitor_enable_receiving=check_errno_on_nonzero_return,
   udev_monitor_receive_device=check_errno_on_null_pointer_return,
   udev_monitor_ref=None,
   udev_monitor_filter_add_match_subsystem_devtype=check_negative_errorcode,
   udev_monitor_filter_add_match_tag=check_negative_errorcode,
   udev_monitor_filter_update=check_errno_on_nonzero_return,
   udev_monitor_filter_remove=check_errno_on_nonzero_return,
   udev_monitor_get_fd=None,
   udev_monitor_new_from_netlink=None,
   udev_monitor_unref=None,
   udev_new=None,
   udev_ref=None,
   udev_set_log_priority=None,
   udev_unref=None
)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Name:     distro.py
# Purpose:  Module to detect if distro types supported by multibootusb (by extracting specific files)
# Authors:  Sundar
# Licence:  This file is a part of multibootusb package. You can redistribute it or modify
# under the terms of GNU General Public License, v.2 or above

import os
import platform
import re
from .iso import *
from .isodump3 import ISO9660
from .gen import *
from . import _7zip


def distro(iso_cfg_ext_dir, iso_link):
    """
    Detect if distro is supported by multibootusb.
    :param iso_cfg_ext_dir: Directory where *.cfg files are extracted.
    :return: Detected distro name as string.
    """
#     iso9660fs = ISO9660(iso_link)
#     iso_file_list = iso9660fs.readDir("/")
    iso_file_list = _7zip.list_iso(iso_link)
    if platform.system() == "Linux" or platform.system() == "Windows":
        for path, subdirs, files in os.walk(iso_cfg_ext_dir):
            for name in files:
                if name.endswith(('.cfg', '.CFG', '.txt', '.TXT', '.lst')):
                    try:
                        # errors='ignore' is required as some files also contain non utf character
                        string = open(os.path.join(path, name), errors='ignore').read()
                    except IOError:
                        return "Read Error."
                    else:
                        if any("f4ubcd" in s.lower() for s in iso_file_list):
                            return "f4ubcd"
                        if re.search(r'ubcd', string, re.I):
                            return "ubcd"
                        elif re.search(r'Super Grub Disk', string, re.I):
                            return "sgrubd2"
                        elif re.search(r'hbcd', string, re.I):
                            return "hbcd"
                        elif re.search(r'systemrescuecd', string, re.I):
                            return "systemrescuecd"
                        elif re.search(r'pmagic|partedmagic', string, re.I) and isolinux_bin_exist(iso_link):
                            return "parted-magic"
                        elif re.search(r'mgalive', string, re.I):  # mounting fat filesystem hard coded in to initrd.
                            # Can be modified only under linux.
                            return "mageialive"
                        elif re.search(r'archisolabel|misolabel', string, re.I):
                            return "arch"
                        elif re.search(r'chakraisolabel', string, re.I):
                            return "chakra"
                        elif re.search(r'kdeosisolabel', string, re.I):
                            return "kaos"
                        elif re.search(r'boot=live', string, re.I) and isolinux_bin_exist(iso_link):
                            return "debian"
                        elif re.search(r'grml', string, re.I) and re.search(r'live-media-path=', string, re.I):
                            return "grml"
                        elif re.search(r'debian-installer', string, re.I) and not any("casper" in s.lower() for s in iso_file_list):
                            return "debian-install"
                        elif re.search(r'solydx', string, re.I):
                            return "solydx"
                        elif re.search(r'knoppix', string, re.I):
                            return "knoppix"
                        elif re.search(r'root=live:CDLABEL=', string, re.I) or re.search(r'root=live:LABEL=', string, re.I):
                            return "fedora"
                        elif re.search(r'redhat', string, re.I):
                            return "redhat"
                        elif re.search(
                                r'slitaz|dban |ophcrack|tinycore|rescue.cpi|xpud|untangle|4mlinux|partition wizard|android-x86.png|'
                                r'riplinux|lebel dummy|http://pogostick.net/~pnh/ntpasswd/|AVG Rescue CD|AntivirusLiveCD|'
                                r'lkrn|Nanolinux', string, re.I):
                            return "slitaz"
                        elif re.search(r'minimal Slackware|Slackware-HOWTO', string, re.I):
                            # for minimal slackware detection
                            return "slitaz"
                        # elif re.search(r'suse', string, re.I):
                        #   return "suse"
                        elif re.search(r'class opensuse', string, re.I):
                            return "opensuse-install"
                        elif re.search(r'boot=casper', string, re.I):
                            return "ubuntu"
                        elif re.search(r'wifislax', string, re.I):
                            return "wifislax"
                        elif re.search(r'slax', string, re.I):
                            return "slax"
                        elif re.search(r'sms.jpg|vector |autoexec', string, re.I) and isolinux_bin_exist(iso_link):
                            return "sms"
                        elif re.search(r'antix', string, re.I):
                            return "antix"
                        elif re.search(r'porteus', string, re.I):
                            return "porteus"
                        elif re.search(r'livecd=livecd|PCLinuxOS', string, re.I):
                            return "pclinuxos"
                        elif re.search(r'looptype=squashfs|http://dee.su/liberte', string, re.I):
                            return "gentoo"
                        elif re.search(r'finnix', string, re.I):
                            return "finnix"
                        elif re.search(r'wifiway', string, re.I):
                            return "wifiway"
                        elif re.search(r'puppy|quirky|fatdog', string, re.I):
                            return "puppy"
                        elif re.search(r'ipcop', string, re.I):
                            return "ipcop"
                        elif re.search(r'ipfire', string, re.I):
                            return "ipfire"
                        elif re.search(r'zenwalk|slack|salix', string, re.I) and re.search(r'live', string, re.I):
                            return "salix-live"
                        elif re.search(r'zenwalk|slack|salix', string, re.I):
                            return "zenwalk"
                        elif re.search(r'ubuntu server', string, re.I):
                            return "ubuntu-server"
                        elif re.search(r'CentOS', string, re.I):
                            return "centos"
                        elif re.search(r'Trinity Rescue Kit', string, re.I):
                            return "trinity-rescue"
                        elif re.search(r'alpine', string, re.I):
                            return "alpine"
                        elif re.search(r'http://support.kaspersky.com', string, re.I):
                            return "kaspersky"
                        elif re.search(r'ALT Linux', string, re.I):
                            return "alt-linux"
                        elif re.search(r'Sergei Strelec', string, re.I):
                            return "Windows"
                        elif re.search(r'ReactOS', string, re.I):
                            return "ReactOS"
                        elif re.search(r'fsecure', string, re.I):
                            return "fsecure"
                        elif re.search(r'default rwp', string, re.I):
                            return "pc-unlocker"
                        elif re.search(r'/system/stage1', string, re.I):
                            return 'pc-tool'
                        elif re.search(r'vba32rescue', string, re.I):
                            return 'grub2only'
                        elif re.search(r'BOOT_IMAGE=rising', string, re.I):
                            return 'rising-av'
                        elif re.search(r'Avira Rescue System', string, re.I):
                            return 'Avira-RS'
                        elif any("alpine-release" in s.lower() for s in iso_file_list):
                            return 'alpine'
                        elif re.search(r'BOOT_IMAGE=insert', string, re.I):
                            return 'insert'

        distro = detect_iso_from_file_list(iso_link)

        if distro:
            return distro
            # FIXME: See the below comments.
#             else:
#                 # FIXME: The idea of detecting as generic is to work like a unetbootin if other methods fails.
#                 #  This simply extracts distro to root of the USB and install syslinux on isolinux.bin directory.
#                 #  All works fine but unable to boot the distro successfully. Also, see the generic section from
#                 #  syslinux, update_cfg and install_distro modules.
#                 if self.isolinux_bin_exist():
#                     return "generic"
        elif str(iso_link).lower().endswith('.iso'):
            return 'memdisk_iso'
        elif str(iso_link).lower().endswith('.img'):
            return 'memdisk_img'
        else:
            return None


def detect_iso_from_file_list(iso_link):
    """
    Fallback detection script from the content of an ISO.
    :return: supported distro as string
    """
    if os.path.exists(iso_link):
        iso_file_list = _7zip.list_iso(iso_link)
        if any("sources" in s.lower() for s in iso_file_list) and any("boot.wim" in s.lower() for s in iso_file_list):
            return "Windows"
        elif any("config.isoclient" in s.lower() for s in iso_file_list):
            return "opensuse"
        elif any("dban" in s.lower() for s in iso_file_list):
            return "slitaz"
        elif any("memtest.img" in s.lower() for s in iso_file_list):
            return "memtest"
        elif any("mt86.png" in s.lower() for s in iso_file_list) and any("isolinux" in s.lower() for s in iso_file_list):
            return 'raw_iso'
        elif any("menu.lst" in s.lower() for s in iso_file_list):
            return "grub4dos"
        elif any("bootwiz.cfg" in s.lower() for s in iso_file_list) and any("bootmenu_logo.png" in s.lower() for s in iso_file_list):
            return "grub4dos_iso"
        else:
            log(iso_file_list)

if __name__ == '__main__':
    iso_cfg_ext_dir = os.path.join(multibootusb_host_dir(), "iso_cfg_ext_dir")
    iso_link = 'Downloads/clonezilla-live-2.4.2-32-amd64.iso'
    iso_extract_file(iso_link, iso_cfg_ext_dir, 'cfg')
    log(distro(iso_cfg_ext_dir))



#!/usr/bin/env python3
# Name:     config.py
# Purpose:  Module to share important variables between various modules. Mainly included so as not to call many
#           functions again and again
# Authors:  Sundar
# Licence:  This file is a part of multibootusb package. You can redistribute it or modify
# under the terms of GNU General Public License, v.2 or above

iso_link = ""
usb_disk = ""
usb_mount = ""
usb_uuid = ""
usb_label = ""
usb_details = ''
image_path = ""
persistence = 0
persistence_available = False
persistence_max_size = 0
distro = ""
status_text = ""
percentage = 0
syslinux_version = ''
uninstall_distro_dir_name = ""
uninstall_distro_dir_path = ""
iso_file_list = ''
iso_bin_dir = ''
process_exist = None
yes = False
cli_dd = False
cli_syslinux = False
usb_gpt = ''

imager_iso_link = ""
imager_usb_disk_selected = ""
imager_lock = ""
imager_percentage = ""
imager_status_text = ""

install_size = ""

editors_linux = ["xdg-open", "gedit", "kate", "kwrite"]
editors_win = ["notepad++.exe", "notepad.exe"]

imager_usb_disk = []

debug = False
